@@ -145,17 +145,18 @@ class Polynomial2D:
             newobj = copy.deepcopy(self)
         # sigclip
         doclip,niter,sigma_level = self.sigclip
-        sentinel = True
-        counter = 0
-        while sentinel:
-            counter += 1
-            newobj._curvefit()
-            newobj.compute(rescale=False)
-            print('Sigma clipping = {0}, sigma level = {1}, iter #{2}'.format(doclip,sigma_level,counter))
-            if not doclip or counter>=niter:
-                break
-            else:
-                newobj._sigclip(sigma_level)
+        if doclip:
+            sentinel = True
+            counter = 0
+            while sentinel:
+                counter += 1
+                newobj._curvefit()
+                newobj.compute(rescale=False)
+                print('Sigma clipping = {0}, sigma level = {1}, iter #{2}'.format(doclip,sigma_level,counter))
+                if counter>=niter:
+                    break
+                else:
+                    newobj._sigclip(sigma_level)
         if self.rescale['RESCALE'][0]:
             newobj.model['YFIT'] = self.rescale['Y'].invtransform(newobj.model['YFIT'])
         self.model = copy.deepcopy(newobj.model)
